@@ -27,7 +27,6 @@
 #' Defaults to `FALSE`.
 #' @param ... additional graphical parameters when `interactive = TRUE`.
 #' Also see [graphics::par()].
-#' @inheritParams getspec
 #'
 #' @inherit getspec details
 #'
@@ -49,25 +48,18 @@
 #'
 #' @examples
 #' # Single image
-#' papilio <- getimg(system.file("testdata/images/papilio.png", package = "pavo"))
+#' papilio <- getimg(system.file("testdata/images/butterflies/papilio.png", package = "pavo"))
 #' papilio_class <- classify(papilio, kcols = 4)
 #'
 #' # Multiple images, with interactive classification and a reference image
 #' snakes <- getimg(system.file("testdata/images/snakes", package = "pavo"))
 #' if (interactive()) {
-#' snakes_class <- classify(snakes, refID = "snake_01", interactive = TRUE)
+#'   snakes_class <- classify(snakes, refID = "snake_01", interactive = TRUE)
 #' }
-#'
 #' @author Thomas E. White \email{thomas.white026@@gmail.com}
 
 classify <- function(imgdat, method = c("kMeans", "kMedoids"), kcols = NULL, refID = NULL, interactive = FALSE,
-                     plotnew = FALSE, col = "red", cores = NULL, ...) {
-  if (!missing(cores)) {
-    warning("'cores' argument is deprecated. See ?future::plan for more info ",
-      "about how you can choose your parallelisation strategy.",
-      call. = FALSE
-    )
-  }
+                     plotnew = FALSE, col = "red", ...) {
 
   ## ------------------------------ Checks ------------------------------ ##
 
