@@ -25,10 +25,9 @@
 #'   `TRUE`)
 #' @param vert.cex size of the points at the vertices (defaults to 1).
 #' @param out.lwd,out.lcol graphical parameters for the tetrahedral outline.
-#' @param margin vector of four numbers specifying drawing margins (defaults to
-#'   c(0, 0, 0, 0)).
 #' @param type accepts a vector of length 1 or 2 with 'p' for points and/or 'l'
 #'   for lines from the point to the base of the tetrahedron.
+#' @param margin Deprecated. Please use the standard [par()] method for custom margins.
 
 #' @inheritParams triplot
 #'
@@ -65,10 +64,11 @@ tetraplot <- function(tcsdata, theta = 45, phi = 10, perspective = FALSE,
                       range = c(1, 2), r = 1e6, zoom = 1,
                       achro = TRUE, achro.col = "grey", achro.size = 1, achro.line = FALSE, achro.lwd = 1, achro.lty = 3,
                       tetrahedron = TRUE, vert.cex = 1, vert.range = c(1, 2), out.lwd = 1, out.lcol = "darkgrey",
-                      margin = c(0, 0, 0, 0), type = "p", labels = FALSE, gamut = FALSE, ...) {
-
-  oldpar <- par(no.readonly = TRUE)
-  on.exit(par(oldpar))
+                      type = "p", labels = FALSE, gamut = FALSE, margin = NULL, ...) {
+  if (!missing("margin")) {
+    message("The 'margin' argument is deprecated, and will be ignored. See ?par() for guidance on
+            setting margins in the standard manner.")
+  }
 
   trange <- function(x, newmin, newmax) {
     (((x - min(x)) * (newmax - newmin)) / (max(x) - min(x))) + newmin
@@ -175,6 +175,7 @@ tetraplot <- function(tcsdata, theta = 45, phi = 10, perspective = FALSE,
   argblank$yaxt <- "n"
   argblank$ylab <- ""
   argblank$xlab <- ""
+  argblank$asp <- 1
 
   if (!plims) {
     prange <- cbind(x = arg$xlim, y = arg$ylim, z = arg$zlim, 1) %*% M
@@ -186,7 +187,7 @@ tetraplot <- function(tcsdata, theta = 45, phi = 10, perspective = FALSE,
   }
 
 
-  par(mar = margin, pty = "s", new = TRUE)
+  par(new = TRUE)
   do.call(plot, argblank)
 
   # Get point coordinates
@@ -410,6 +411,7 @@ tetraplot <- function(tcsdata, theta = 45, phi = 10, perspective = FALSE,
 
   if (gamut) {
     maxgamut <- attr(tcsdata, "data.maxgamut")
+    maxgamut <- na.omit(maxgamut)
     colnames(maxgamut) <- c("x", "y", "z")
     attr(maxgamut, "clrsp") <- "tcs"
     tryCatch(vol(maxgamut, grid = FALSE),
